==> qtjambi-debuginfo-macos-5.15.17.jar: sources/QtJambiCore/QtMessageHandler_shell.cpp <==
#include "QtMessageHandler_shell.h"
#include <QtJambi/RegistryAPI>
#include <QtJambi/FunctionPointer>
#include <QtJambi/Cast>
// emitting (writeShellConstructor)
void deleter_QtMessageHandler(void *ptr,bool) { delete reinterpret_cast<QtMessageHandler_shell*>(ptr); }


QtMessageHandler_shell::QtMessageHandler_shell()
    : FunctionalBase()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QtMessageHandler_shell::QtMessageHandler_shell()")
    QtMessageHandler_shell::__shell()->constructed(typeid(QtMessageHandler));
}

// emitting (writeShellDestructor)
QtMessageHandler_shell::~QtMessageHandler_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QtMessageHandler_shell::~QtMessageHandler_shell()", QtMessageHandler_shell::__shell())
    if(m_functionPointerDeleter)
        m_functionPointerDeleter();
    QtMessageHandler_shell::__shell()->destructed(typeid(QtMessageHandler));
}

// construct QtMessageHandler_shell
void __qt_construct_QtMessageHandler_0(void* __qtjambi_ptr, JNIEnv*, jobject, jvalue*)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QtMessageHandler")
    new (__qtjambi_ptr) QtMessageHandler_shell();
}
// destruct QtMessageHandler_shell
void __qt_destruct_QtMessageHandler(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QtMessageHandler")
    reinterpret_cast<QtMessageHandler_shell*>(ptr)->~QtMessageHandler_shell();
}

void QtMessageHandler_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QtMessageHandler_shell*>(ptr)->QtMessageHandler_shell::__shell()->tryDeleteShell(typeid(QtMessageHandler));
}

QtJambiShell* QtMessageHandler_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QtMessageHandler_shell) ); }

QtMessageHandler_shell::Functor::Functor(QtMessageHandler_shell& functional) : FunctorBase(typeid(QtMessageHandler), functional) {}

QtMessageHandler_shell::Functor::Functor(const Functor& functor) : FunctorBase(functor) {}

QtMessageHandler_shell::Functor::~Functor() {}

void QtMessageHandler_shell::Functor::operator()(QtMsgType arg__1, const QMessageLogContext& arg__2, const QString& arg__3)
{
    if (jmethodID method_id = javaMethod()) {
        if (JniEnvironment env{500}) {
            JavaException throwable;
            if(env->ExceptionCheck()){
                jthrowable t = env->ExceptionOccurred();
                env->ExceptionClear();
                throwable = JavaException(env, t);
            }
            QTJAMBI_TRY {
                if (jobject __java_this = getJavaObjectLocalRef(env)) {
                    jobject __java_arg__1 = qtjambi_cast<jobject>(env, arg__1);
                    jobject __java_arg__2 = qtjambi_cast<jobject>(env, &arg__2);
                    QTJAMBI_INVALIDATE_AFTER_USE(env, __java_arg__2);
                    jstring __java_arg__3 = qtjambi_cast<jstring>(env, arg__3);
                    env->CallVoidMethod(__java_this, method_id, __java_arg__1, __java_arg__2, __java_arg__3);
                    JavaException::check(env QTJAMBI_STACKTRACEINFO );
                }
            } QTJAMBI_CATCH(const JavaException& exn) {
                throwable.addSuppressed(env, exn);
            } QTJAMBI_TRY_END
            throwable.raiseInJava(env);
        }
    }
}

void QtMessageHandler_shell::getFunctional(JNIEnv *env, void* result)
{
        jobject __this = QtMessageHandler_shell::__shell()->getJavaObjectLocalRef(env);
        uint hash = QtJambiAPI::getJavaObjectIdentity(env, __this);
        *reinterpret_cast<QtMessageHandler*>(result) = qtjambi_function_pointer<14,void(QtMsgType,const QMessageLogContext&,const QString&)>(Functor(*this), hash, &m_functionPointerDeleter, reverseFunctionGetter ? nullptr : &reverseFunctionGetter);
}

jobject QtMessageHandler_shell::resolveFunctional(JNIEnv * env, const QtMessageHandler* function)
{
    if(function && reverseFunctionGetter){
        if(const QtMessageHandler_shell::Functor* functor = reverseFunctionGetter(*function)){
            return functor->getJavaObjectLocalRef(env);
        }
    }
    return nullptr;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QtMessageHandler_00024Impl_00024ConcreteWrapper_accept_1native__IJLjava_lang_String_2)
(JNIEnv *__jni_env, jobject __this, jint arg__1, QtJambiNativeID arg__2, jstring arg__3)
{
    QTJAMBI_NATIVE_METHOD_CALL("QtMessageHandler(...)")
    QtJambiScope __qtjambi_scope(__jni_env, __this);
    Q_UNUSED(__qtjambi_scope)
    QTJAMBI_TRY {
        QtMessageHandler* function = QtJambiAPI::convertJavaInterfaceToNative<QtMessageHandler>(__jni_env, __this);
        QtJambiAPI::checkNullPointer(__jni_env, function);
        qint32 __qt_arg__1 = qtjambi_cast<qint32>(__jni_env, arg__1);
        const QMessageLogContext& __qt_arg__2 = QtJambiAPI::objectReferenceFromNativeId<QMessageLogContext>(__jni_env, arg__2);
        QString  __qt_arg__3 = qtjambi_cast<QString >(__jni_env, arg__3);
        (*function)(QtMsgType(__qt_arg__1), __qt_arg__2, __qt_arg__3);
    } QTJAMBI_CATCH(const JavaException& exn) {
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QtMessageHandler_00024Impl_initialize_1native)
(JNIEnv *__jni_env, jclass __jni_class, jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QtMessageHandler_shell")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QtMessageHandler_0, sizeof(QtMessageHandler_shell), typeid(QtMessageHandler), &deleter_QtMessageHandler);
    } QTJAMBI_CATCH(const JavaException& exn) {
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
}

std::function<const QtMessageHandler_shell::Functor*(QtMessageHandler)> QtMessageHandler_shell::reverseFunctionGetter = std::function<const QtMessageHandler_shell::Functor*(QtMessageHandler)>();

void initialize_meta_info_QtMessageHandler(){
    using namespace RegistryAPI;
    registerFunctionalTypeInfo<QtMessageHandler, QtMessageHandler_shell>("QtMessageHandler", "io/qt/core/QtMessageHandler",
                              &deleter_QtMessageHandler,
                              &__qt_destruct_QtMessageHandler,
                              {ConstructorInfo(&__qt_construct_QtMessageHandler_0, nullptr)},
                              {FunctionInfo("accept", "(Lio/qt/core/QtMsgType;Lio/qt/core/QMessageLogContext;Ljava/lang/String;)V", FunctionInfo::Abstract)});
}

==> qtjambi-debuginfo-macos-6.7.2.jar: sources/QtJambiCore/QtMessageHandler_shell.cpp <==
#include "QtMessageHandler_shell.h"
#include <QtJambi/RegistryAPI>
#include <QtJambi/FunctionPointer>
#include <QtJambi/Cast>
// emitting (writeShellConstructor)
void deleter_QtMessageHandler(void *ptr,bool) { delete reinterpret_cast<QtMessageHandler_shell*>(ptr); }


QtMessageHandler_shell::QtMessageHandler_shell()
    : FunctionalBase()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QtMessageHandler_shell::QtMessageHandler_shell()", this)
    QtMessageHandler_shell::__shell()->constructed(typeid(QtMessageHandler));
}

// emitting (writeShellDestructor)
QtMessageHandler_shell::~QtMessageHandler_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QtMessageHandler_shell::~QtMessageHandler_shell()", this)
    if(m_functionPointerDeleter)
        m_functionPointerDeleter();
    QtMessageHandler_shell::__shell()->destructed(typeid(QtMessageHandler));
}

// construct QtMessageHandler_shell
void __qt_construct_QtMessageHandler(void* __qtjambi_ptr, JNIEnv*, jobject, jvalue*, bool, bool, bool)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QtMessageHandler")
    new (__qtjambi_ptr) QtMessageHandler_shell();
}
// destruct QtMessageHandler_shell
void __qt_destruct_QtMessageHandler(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QtMessageHandler")
    reinterpret_cast<QtMessageHandler_shell*>(ptr)->~QtMessageHandler_shell();
}

void QtMessageHandler_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QtMessageHandler_shell*>(ptr)->QtMessageHandler_shell::__shell()->tryDeleteShell(typeid(QtMessageHandler));
}

QtJambiShell* QtMessageHandler_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QtMessageHandler_shell) ); }

QtMessageHandler_shell::Functor::Functor(QtMessageHandler_shell& functional) : FunctorBase(typeid(QtMessageHandler), functional) {}

QtMessageHandler_shell::Functor::Functor(const Functor& functor) : FunctorBase(functor) {}

QtMessageHandler_shell::Functor::~Functor() {}

void QtMessageHandler_shell::Functor::operator()(QtMsgType arg__1, const QMessageLogContext& arg__2, const QString& arg__3)
{
    if (jmethodID method_id = javaMethod()) {
        if (JniEnvironment env{500}) {
            JavaException throwable;
            if(env->ExceptionCheck()){
                jthrowable t = env->ExceptionOccurred();
                env->ExceptionClear();
                throwable = JavaException(env, t);
            }
            QTJAMBI_TRY {
                if (jobject __java_this = getJavaObjectLocalRef(env)) {
                    jobject __java_arg__1 = qtjambi_cast<jobject>(env, arg__1);
                    jobject __java_arg__2 = qtjambi_cast<jobject>(env, &arg__2);
                    QTJAMBI_INVALIDATE_AFTER_USE(env, __java_arg__2);
                    jstring __java_arg__3 = qtjambi_cast<jstring>(env, arg__3);
                    env->CallVoidMethod(__java_this, method_id, __java_arg__1, __java_arg__2, __java_arg__3);
                    JavaException::check(env QTJAMBI_STACKTRACEINFO );
                }
            } QTJAMBI_CATCH(const JavaException& exn) {
                throwable.addSuppressed(env, exn);
            } QTJAMBI_TRY_END
            throwable.raiseInJava(env);
        }
    }
}

void QtMessageHandler_shell::getFunctional(JNIEnv *env, void* result)
{
        jobject __this = QtMessageHandler_shell::__shell()->getJavaObjectLocalRef(env);
        uint hash = QtJambiAPI::getJavaObjectIdentity(env, __this);
        *reinterpret_cast<QtMessageHandler*>(result) = qtjambi_function_pointer<14,void(QtMsgType,const QMessageLogContext&,const QString&)>(Functor(*this), hash, &m_functionPointerDeleter, reverseFunctionGetter ? nullptr : &reverseFunctionGetter);
}

jobject QtMessageHandler_shell::resolveFunctional(JNIEnv * env, const void* functionPtr, bool* ok)
{
    if(functionPtr && reverseFunctionGetter){
        const QtMessageHandler& function = *reinterpret_cast<const QtMessageHandler*>(functionPtr);
        if(const QtMessageHandler_shell::Functor* functor = reverseFunctionGetter(function)){
            if(ok)
                *ok = true;
            return functor->getJavaObjectLocalRef(env);
        }
        if(ok)
            *ok = !function;
    }
    return nullptr;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QtMessageHandler_00024Impl_00024ConcreteWrapper_accept_1native__IJLjava_lang_String_2)
(JNIEnv *__jni_env, jobject __this, jint arg__1, QtJambiNativeID arg__2, jstring arg__3)
{
    QTJAMBI_NATIVE_METHOD_CALL("QtMessageHandler(...)")
    QTJAMBI_TRY {
        QtMessageHandler* function = QtJambiAPI::convertJavaInterfaceToNative<QtMessageHandler>(__jni_env, __this);
        QtJambiAPI::checkNullPointer(__jni_env, function);
        qint32 __qt_arg__1 = qtjambi_cast<qint32>(__jni_env, arg__1);
        const QMessageLogContext& __qt_arg__2 = QtJambiAPI::objectReferenceFromNativeId<QMessageLogContext>(__jni_env, arg__2);
        QString __qt_arg__3 = qtjambi_cast<QString>(__jni_env, arg__3);
        (*function)(QtMsgType(__qt_arg__1), __qt_arg__2, __qt_arg__3);
    } QTJAMBI_CATCH(const JavaException& exn) {
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QtMessageHandler_00024Impl_initialize_1native)
(JNIEnv *__jni_env, jclass __jni_class, jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QtMessageHandler_shell")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QtMessageHandler, sizeof(QtMessageHandler_shell), typeid(QtMessageHandler), 0, &deleter_QtMessageHandler);
    } QTJAMBI_CATCH(const JavaException& exn) {
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
}

std::function<const QtMessageHandler_shell::Functor*(QtMessageHandler)> QtMessageHandler_shell::reverseFunctionGetter = std::function<const QtMessageHandler_shell::Functor*(QtMessageHandler)>();

void initialize_meta_info_QtMessageHandler(){
    using namespace RegistryAPI;
    registerFunctionalTypeInfo<QtMessageHandler, QtMessageHandler_shell>("QtMessageHandler", "io/qt/core/QtMessageHandler",
                              false,
                              &deleter_QtMessageHandler,
                              &__qt_destruct_QtMessageHandler,
                              {ConstructorInfo(&__qt_construct_QtMessageHandler, nullptr)},
                              {FunctionInfo("accept", "(Lio/qt/core/QtMsgType;Lio/qt/core/QMessageLogContext;Ljava/lang/String;)V", FunctionInfo::Abstract)});
}
